@@ -14,7 +14,9 @@ class Connection:
         asyncio.run(self.async_check())
 
     async def async_check(self):
-        await asyncpg.connect(f'postgresql://{self.__user}:{self.__password}@{self.__host}/{self.__database}')
+        await asyncpg.connect(
+            f'postgresql://{self.__user}:{self.__password}@{self.__host}:{self.__port}/{self.__database}')
 
     async def get_connection(self) -> asyncpg.connection.Connection:
-        return await asyncpg.connect(f'postgresql://{self.__user}:{self.__password}@{self.__host}/{self.__database}')
+        return await asyncpg.connect(
+            f'postgresql://{self.__user}:{self.__password}@{self.__host}:{self.__port}/{self.__database}')
