@@ -1,5 +1,5 @@
 from jija_orm.executors import operators, functions, comparators, sql_object
-from jija_orm.executors import executors
+from jija_orm import executors
 
 
 table_selector = executors.Executor(
