@@ -661,8 +661,21 @@ class Migration:
 
     @classmethod
     async def execute(cls):
+        commands_query = []
         for command in cls.commands:
-            await command.execute()
+            commands_query.append(command.get_query())
+
+        connection = await config.JijaORM.get_connection()
+
+        print(f'Using migration {cls.id}', end='')
+
+        try:
+            await connection.execute('\n'.join(commands_query))
+            print(' [OK]')
+        except Exception as exception:
+            print(' [ERROR]\n')
+            raise exception
+
 
     @staticmethod
     def get_constructor(commands):
